@@ -9,7 +9,7 @@
 #
 package Config::Model::Tester;
 {
-  $Config::Model::Tester::VERSION = '2.019';
+  $Config::Model::Tester::VERSION = '2.020';
 }
 
 use Test::More;
@@ -222,7 +222,7 @@ sub run_model_test {
             } 
         }
 
-        $inst->write_back( );
+        $inst->write_back( force => 1 );
         ok( 1, "$model_test write back done" );
         
         if (my $fc = $t->{file_content}) {
@@ -350,7 +350,7 @@ Config::Model::Tester - Test framework for Config::Model
 
 =head1 VERSION
 
-version 2.019
+version 2.020
 
 =head1 SYNOPSIS
 
@@ -544,6 +544,9 @@ Verify annotation extracted from the configuration file comments:
 =item *
 
 Write back the config data in C<< wr_root/<subtest name>/ >>. 
+Note that write back is forced, so the tested configuration files are
+written back even if the configuration values were not changed during the test.
+
 You can skip warning when writing back with:
 
     no_warnings => 1,
